# moyo

Document: https://docs.rs/moyo/latest/moyo/

## Module dependency

```
math <- base <- data <- identify <- standardize <- lib
        ^---- search <--------------|
```

## Debugging

```shell
RUST_LOG=debug cargo test -- --nocapture
```
